@@ -1,7 +1,7 @@
 package Log::ger::Format::Block;
 
-our $DATE = '2017-06-25'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $DATE = '2017-06-30'; # DATE
+our $VERSION = '0.004'; # VERSION
 
 use strict;
 use warnings;
@@ -25,8 +25,8 @@ sub get_hooks {
 
                 my %args = @_;
                 for my $r (@{ $args{routines} }) {
-                    my ($coderef, $name, $flags) = @$r;
-                    next unless $flags & 1; # routine is a log_LEVEL routine
+                    my ($coderef, $name, $lnum, $type) = @$r;
+                    next unless $type =~ /\Alog_/;
                     # avoid prototype mismatch warning when redefining
                     if ($args{target} eq 'package' ||
                             $args{target} eq 'object') {
@@ -56,7 +56,7 @@ Log::ger::Format::Block - Use formatting using block instead of sprintf-style
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
